/********************************************************************/
/*    ...                                                           */
/* Program name: TESTDLEX.C                                         */
/*                                                                  */
/* Description:  Source file to TEST Windows 16 RAS Dialer          */
/*               Extension DLL                                      */
/*                                                                  */
/* Statement:     Licensed Materials - Property of IBM              */
/*                                                                  */
/*                5622-960 (C) Copyright IBM Corp. 1996             */
/*                                                                  */
/*                U.S. Government Users Restricted Rights - use,    */
/*                duplication or disclosure restricted by GSA ADP   */
/*                Schedule Contract with IBM Corp.                  */
/*                                                                  */
/********************************************************************/

#include <windows.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ras.h>
#include <raserror.h>
#include "testdlex.h"
#include "win16ras.h"


HFONT   hFont;                          // status line font handle

int PASCAL WinMain( HANDLE hInstance, HANDLE hPrevInstance,
                    LPSTR lpszCmdLine, int nCmdShow )
{
  HWND hdlg;                            // main dialog handle
  MSG msg;                              // incoming message
  DLGPROC dlgproc;                      // dialog procedure pointer
  BOOL connActive;                      // connection active

  // save hInstance
  vhInstance = hInstance;

  // load application icon - needed to paint window when minimized */
  vhiconAppl = LoadIcon( hInstance, MAKEINTRESOURCE( IDC_SAMPICON ) );

  // bind dialog procedure to instance data
  dlgproc = MakeProcInstance( (DLGPROC)TESTDLEXDlgProc, hInstance );

  // create and display dialog - pass any initial values
  // to the dialog

  hdlg = CreateDialog( hInstance, "IDD_TESTDLEX",
                       GetDesktopWindow(), dlgproc );
  ShowWindow( hdlg, nCmdShow );
  UpdateWindow( hdlg );

  // main message loop - ensure dialog messages get posted to the
  // appropriate procedure

  while( GetMessage( &msg, (HWND)NULL, 0,0 ) )
  {
    if (!IsDialogMessage( hdlg, &msg ))
    {
      TranslateMessage( &msg );
      DispatchMessage( &msg );
    }
  }

  /* free dialog procedure from instance data */
  FreeProcInstance( dlgproc );

  return msg.wParam;
}

 BOOL __export CALLBACK TESTDLEXDlgProc( HWND hdlg, UINT message,
                                        WPARAM wParam, LPARAM lParam )
{
int  connActive;                      /* connection active        */
char  szBuf[256];                         /* general purpose buffer */
int rc;
static char *szUpDown[]={"down","up"};

  switch( message )
  {
    case WM_INITDIALOG:
      MQDX_Initialize( hdlg, (FARPROC)NULL, (FARPROC)NULL );
      return (TRUE);

    case WM_COMMAND:
      switch( wParam )
      {
        case IDM_START:
                      MQDX_StartDialer();
                      break;

        case IDM_STATUS:
                      connActive = MQDX_IsDialerConnectionActive();
                      wsprintf( (LPSTR)szBuf, "Connection is %s (%d)",
                                szUpDown[connActive==0 ? 0 : 1],connActive);
                      MessageBox( (HWND)NULL, (LPSTR)szBuf, vszAppName, MB_OK );
                      break;

        case IDM_STOP:

                      connActive = MQDX_IsDialerConnectionActive();

                      if(connActive)
                      {
                        MessageBeep( MB_ICONEXCLAMATION );
                        wsprintf( (LPSTR)szBuf, "Close Connection?" );
                        rc= MessageBox( (HWND)NULL, (LPSTR)szBuf, vszAppName, MB_OKCANCEL );

                        switch(rc)
                        {
                         case IDOK:   // hang-up the RAS connection

                                      MQDX_StopDialer();
                                      break;
                         case IDCANCEL:
                                      break;

                        }
                      }
                      break;

        case IDM_EXIT:
                     DestroyWindow( hdlg );
                     return TRUE;

        default:
          break;
      }
      break;

    case WM_CLOSE:
      DestroyWindow( hdlg );
      return (TRUE);

    case WM_DESTROY:

      /* post quit message to exit */
      PostQuitMessage( 0 );
      break;

  }
  return FALSE;
}
