//******************************************************************
//
// Program name: WIN16RAS.H
//
// Description:  Header file for the Windows 16 BIT RAS Dialer
//               Extension.
//
// Statement:     Licensed Materials - Property of IBM
//
//                5622-960 (C) Copyright IBM Corp. 1996
//
//                U.S. Government Users Restricted Rights - use,
//                duplication or disclosure restricted by GSA ADP
//                Schedule Contract with IBM Corp.
//
//******************************************************************

//******************************************************************
//
// Dialer Exit Functions:
//
//   MQDX_Initialize               : Initialise interface
//   MQDX_WhichFeaturesSupported   : Return which features supported
//   MQDX_StartDialer              : Start dialer
//   MQDX_IsDialerConnectionActive : Check status of connection
//   MQDX_StopDialer               : Stop dialer
//   MQDX_Terminate                : Terminate interface
//
//******************************************************************

 BOOL _loadds _far MQDX_Initialize( HWND hwnd, FARPROC lpfnConnectionNowUp,
                                   FARPROC lpfnConnectionNowDown );
 LONG _loadds _far MQDX_WhichFeaturesSupported( void );
 UINT _loadds _far MQDX_StartDialer(void);
 BOOL _loadds _far MQDX_IsDialerConnectionActive( void );
 UINT _loadds _far MQDX_StopDialer( void );
 void _loadds _far MQDX_Terminate( void );

//
//==============   Dialer Exit Constants   =========================
//
//
//   FunctionsSupported bit flags:
//
//   xxxx xxxx xxxx xxx1          CALLBACK_ON_CONNECTION_CHANGE
//   xxxx xxxx xxxx xx1x          SERVER_INITIATED_CALLS
//
//==================================================================
//
//  Usage:
//
//  CALLBACK_ON_CONNECTION_CHANGE:
//
//     Use this when your app will 'callback' when the line
//           connection status changes. (win16ras example uses it)
//
//  SERVER_INITIATED_CALLS:
//
//     Use this when your application is a 'listener' waiting for
//     incoming calls and can provide 'callback' status to MQW
//
//     The advantage of using this is that MQW does not start the
//     channels until the incoming call is received , thus saving
//     system resource.
//
//------------------------------------------------------------------

#define CALLBACK_ON_CONNECTION_CHANGE  0x0001
#define SERVER_INITIATED_CALLS         0x0002


//======================  Dialog/string identifiers  =================================

#define IDC_GROUP1            1000
#define IDC_RASLIST           1001
#define IDC_CONNECT           1002
#define IDC_INFOLINE          1003
#define IDC_INFOLINE2         1004
#define IDS_DEFAULT_INFO_TEXT 1005
#define IDS_APP_NAME          1006
#define IDC_STATIC            9999


//======================  Miscellaneous  =============================================

#define GROUP_BORDER      3
#define CCHBUFFER       256
#define ICON_WIDTH       32
#define ICON_HEIGHT      32
#define INFOLINE_BORDER   4
#define INFOLINE_HEIGHT  (INFOLINE_BORDER + ICON_HEIGHT + INFOLINE_BORDER)
#define MQMAN_WIDTH      (INFOLINE_BORDER + ICON_WIDTH + INFOLINE_BORDER)
#define MQMAN_HEIGHT     (INFOLINE_HEIGHT)
#define INFO_CLASSNAME   "AMQ_CLASS_INFO"
#define INFO2_CLASSNAME   "AMQ_CLASS_INFO2"
#define INFO_SIZE        (200 * 2)
#define TITLE_SIZE       (80 * 2)
#define VI_DIAL_TIMERID   1
#define VI_DIAL_TIMEOUT 300

//======================  GLOBAL VARIABLES   =========================================

HICON     vahIcon[8];                     // icon array(application & dialing)
COLORREF  vclrrefDlgTextBkgnd = 0;        // dialog background colour
COLORREF  vclrrefDlgTextFrgnd = 0;        // dialog foreground colour
WNDPROC   vDefGroupWinProc = NULL;        // default static window procedure
HINSTANCE vhInstance;                     // DLL instance handle
HRASCONN  vhRasConn;                      // RAS connection handle
HBRUSH    vhbrushDlgBkgnd;                // brush representing dialog background
HPEN     vhpenEditTopBorder;             // left/top LB colour for 3D effect
HWND      vhwnd = 0;                      // MQWIN window handle
HWND      vhwndGroup1;                    // groupbox window handle
HWND      vhwndInfoLine;                  // information line window handle
HWND      vhwndIconLine;                  // information line window handle
HWND      vhwndRASList;                   // RAS Connections listbox window handle
FARPROC   vlpfnConnectionNowUp = 0L;      // connection made callback
FARPROC   vlpfnConnectionNowDown = 0L;    // connection dropped callback
UINT      vndxIcon = 0;                   // icon array index (0=application)
char      vszAppName[TITLE_SIZE];         // application title text
char      vszInfoText[INFO_SIZE];         // default information text
UINT      vtimerDial;                     // dial timer ID
UINT      vuMessageRAS = WM_RASDIALEVENT; // default RAS message ID
UINT      vhwndConnect = 0;               // flags connect dialogue open
BOOL      vWaitForHangUp=0;               // Wait for hang up completion
BOOL      vNoExitHangUp=0;                // Hang up on link termination
char      vszEntryName[RAS_MaxEntryName]; // Current entry name

//======================= TYPE DEFINITIONS ==========================================

// structure used to hold RAS entries information
typedef struct _RASENTRIES
{
  DWORD  cEntry;                           // # of RAS entries
  LPRASENTRYNAME lpRasEntry;               // RAS entry information

} RASENTRIES, FAR *PRASENTRIES;

//======================= FUNCTION DECLARATIONS =====================================

// Select RAS connection dialog procedure
BOOL __export CALLBACK SelectDlgProc( HWND hdlg, UINT message,
                                      WPARAM wParam, LPARAM lParam );
// Groupbox window procedure
LRESULT __export CALLBACK GroupWinProc( HWND hwnd, UINT msg,
                                        WPARAM wParam, LPARAM lParam );
// Information window procedure
LRESULT __export CALLBACK InfoWinProc( HWND hwnd, UINT msg,
                                       WPARAM wParam, LPARAM lParam );

// Animated ICON proc
LRESULT __export CALLBACK IconWinProc( HWND hwnd, UINT msg,
                                       WPARAM wParam, LPARAM lParam );

// Function to set the the text in the information line
BOOL SetInfoText( HWND hwndParent, LPSTR pszInfoText );

//  Get a handle to current connection

static  UINT SetConnectionHandle(void );       // return TRUE if handle set

// Hangup the phone line

VOID HangUp(HRASCONN hRas);
